import 'package:flutter/material.dart';
import 'package:path_stack/path_stack.dart';

import 'simple_tab_example_pages.dart';

/// 3 top-level routes, all mapped to an enum value.
///
/// Routes 1 and 2 retain state. Notice their buildCount's updating when you switch tabs.
/// The 3rd route is set to `maintainState: false`, so build count will always reset to 0
enum PageType { Home, Explore, Settings }

class SimpleTabExample extends StatefulWidget {
  @override
  _SimpleTabExampleState createState() => _SimpleTabExampleState();
}

class _SimpleTabExampleState extends State<SimpleTabExample> {
  PageType _tabType = PageType.Home;
  late String currentPath = "$_tabType";

  @override
  Widget build(BuildContext context) {
    return PathStack(
      // Path is the source of truth for each stack
      path: "$currentPath",
      transitionBuilder: (_, child, anim) => FadeTransition(opacity: anim, child: child), // Optional
      scaffoldBuilder: (_, stack) => TabScaffold(_tabType, child: stack, onTabPressed: _handleTabPressed),
      entries: [
        PathStackEntry(path: "${PageType.Home}", builder: (_, args) => HomePage()),
        PathStackEntry(path: "${PageType.Settings}", builder: (_, args) => SettingsPage()),
        PathStackEntry(path: "${PageType.Explore}", builder: (_, args) => ExplorePage(), maintainState: false),
      ],
    );
  }

  void _handleTabPressed(PageType value) => setState(() => _tabType = value);
}
